summaryrefslogtreecommitdiff
path: root/lib/Support/raw_ostream.cpp
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2010-04-07 22:58:41 +0000
committerChris Lattner <sabre@nondot.org>2010-04-07 22:58:41 +0000
commit75361b69f3f327842b9dad69fa7f28ae3b688412 (patch)
tree5308b9ca3c47b10d83068cbbd7c13bcf8cca7f73 /lib/Support/raw_ostream.cpp
parente3a601b648e4cbb916e33f969a1b9d3d40b36734 (diff)
downloadllvm-75361b69f3f327842b9dad69fa7f28ae3b688412.tar.gz
llvm-75361b69f3f327842b9dad69fa7f28ae3b688412.tar.bz2
llvm-75361b69f3f327842b9dad69fa7f28ae3b688412.tar.xz
rename llvm::llvm_report_error -> llvm::report_fatal_error
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@100709 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Support/raw_ostream.cpp')
-rw-r--r--lib/Support/raw_ostream.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/Support/raw_ostream.cpp b/lib/Support/raw_ostream.cpp
index f59bd0d903..7a02db1aeb 100644
--- a/lib/Support/raw_ostream.cpp
+++ b/lib/Support/raw_ostream.cpp
@@ -57,11 +57,11 @@ raw_ostream::~raw_ostream() {
delete [] OutBufStart;
// If there are any pending errors, report them now. Clients wishing
// to avoid llvm_report_error calls should check for errors with
// has_error() and clear the error flag with clear_error() before
// destructing raw_ostream objects which may have errors.
if (Error)
- llvm_report_error("IO failure on output stream.");
+ report_fatal_error("IO failure on output stream.");
}
// An out of line virtual method to provide a home for the class vtable.
@@ -57,11 +57,11 @@ raw_ostream::~raw_ostream() {
delete [] OutBufStart;
// If there are any pending errors, report them now. Clients wishing
- // to avoid llvm_report_error calls should check for errors with
+ // to avoid report_fatal_error calls should check for errors with
// has_error() and clear the error flag with clear_error() before
// destructing raw_ostream objects which may have errors.